import axios from 'axios';
import { config } from '../../config';
const base = "http://localhost:" + config.internal_port

let access_token;
let axios_config;

beforeAll(async () => {
    const res = await axios.post(base + '/api/auth/login', { username: "demo", password: "demo" });
    access_token = res.data["access_token"];
    axios_config = {
        headers: { "authorization": "Bearer " + access_token },
        validateStatus: undefined
    };
});

describe('POST /api/runners/me/forgot invalid syntax/mail should return fail', () => {
    it('get without mail return 404', async () => {
        const res = await axios.post(base + '/api/runners/forgot', null, axios_config);
        expect(res.status).toEqual(404);
        expect(res.headers['content-type']).toContain("application/json");
    });
    it('get without bs mail return 404', async () => {
        const res = await axios.post(base + '/api/runners/forgot?mail=asdasdasdasdasd@tester.test.dev.lauf-fuer-kaya.de', null, axios_config);
        expect(res.status).toEqual(404);
        expect(res.headers['content-type']).toContain("application/json");
    });
});
describe('POST /api/runners/me/forgot 2 times within timeout should return fail', () => {
    let added_runner;
    it('registering as citizen should return 200', async () => {
        const res = await axios.post(base + '/api/runners/register', {
            "firstname": "string",
            "middlename": "string",
            "lastname": "string",
            "email": "citizen420@dev.lauf-fuer-kaya.de"
        }, axios_config);
        expect(res.status).toEqual(200);
        expect(res.headers['content-type']).toContain("application/json");
        added_runner = res.data;
    });
    it('post with valid mail should return 200', async () => {
        const res = await axios.post(base + '/api/runners/forgot?mail=' + added_runner.email, null, axios_config);
        expect(res.status).toEqual(200);
        expect(res.headers['content-type']).toContain("application/json");
    });
    it('2nd post with valid mail should return 400', async () => {
        const res = await axios.post(base + '/api/runners/forgot?mail=' + added_runner.email, null, axios_config);
        expect(res.status).toEqual(400);
        expect(res.headers['content-type']).toContain("application/json");
    });
});
